==> jakarta-concurrency-tck-1.0.0.zip: concurrency-tck/src/com/sun/ts/tests/concurrency/spec/ContextService/contextPropagate_servlet/DeserializeServlet.java <==
/*
 * Copyright (c) 2013, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package com.sun.ts.tests.concurrency.spec.ContextService.contextPropagate_servlet;

import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;

@WebServlet("/DeserializeServlet")
public class DeserializeServlet extends HttpServlet {

  @Override
  protected void service(HttpServletRequest req, HttpServletResponse resp)
      throws ServletException, IOException {

    try {
      Object proxy = Util.lookupDefaultContextService().createContextualProxy(
          new TestJNDIRunnableWork(), Runnable.class, TestWorkInterface.class,
          Serializable.class);
      ByteArrayOutputStream bout = new ByteArrayOutputStream();
      ObjectOutputStream out = new ObjectOutputStream(bout);
      out.writeObject(proxy);
      out.close();
      byte[] bytes = bout.toByteArray();
      ObjectInputStream in = new ObjectInputStream(
          new ByteArrayInputStream(bytes));
      proxy = in.readObject();
      resp.getWriter().write(proxy.toString());
    } catch (Exception e) {
      throw new ServletException(e);
    }
  }
}

==> jakarta-concurrency-tck-2.0.1.zip: concurrency-tck/src/com/sun/ts/tests/concurrency/spec/ContextService/contextPropagate_servlet/DeserializeServlet.java <==
/*
 * Copyright (c) 2013, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package com.sun.ts.tests.concurrency.spec.ContextService.contextPropagate_servlet;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;

import jakarta.servlet.ServletException;
import jakarta.servlet.annotation.WebServlet;
import jakarta.servlet.http.HttpServlet;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;

@WebServlet("/DeserializeServlet")
public class DeserializeServlet extends HttpServlet {

  @Override
  protected void service(HttpServletRequest req, HttpServletResponse resp)
      throws ServletException, IOException {

    try {
      Object proxy = Util.lookupDefaultContextService().createContextualProxy(
          new TestJNDIRunnableWork(), Runnable.class, TestWorkInterface.class,
          Serializable.class);
      ByteArrayOutputStream bout = new ByteArrayOutputStream();
      ObjectOutputStream out = new ObjectOutputStream(bout);
      out.writeObject(proxy);
      out.close();
      byte[] bytes = bout.toByteArray();
      ObjectInputStream in = new ObjectInputStream(
          new ByteArrayInputStream(bytes));
      proxy = in.readObject();
      resp.getWriter().write(proxy.toString());
    } catch (Exception e) {
      throw new ServletException(e);
    }
  }
}
